globals [
  regions ; The number of regions - currently 5
  pop1 ; population in Region 1
  pop2 ; population in Region 2
  pop3 ; population in Region 3
  pop4 ; population in Region 4
  pop5 ; population in Region 5
  pop11 ; population in Region 1 with hometown as Region 1
  pop12 ; population in Region 1 with hometown as Region 2
  pop13 ; population in Region 1 with hometown as Region 3
  pop14 ; population in Region 1 with hometown as Region 4
  pop15 ; population in Region 1 with hometown as Region 5
  pop21 ; population in Region 2 with hometown as Region 1
  pop22 ; population in Region 2 with hometown as Region 2
  pop23 ; population in Region 2 with hometown as Region 3
  pop24 ; population in Region 2 with hometown as Region 4
  pop25 ; population in Region 2 with hometown as Region 5
  pop31 ; population in Region 3 with hometown as Region 1
  pop32 ; population in Region 3 with hometown as Region 2
  pop33 ; population in Region 3 with hometown as Region 3
  pop34 ; population in Region 3 with hometown as Region 4
  pop35 ; population in Region 3 with hometown as Region 5
  pop41 ; population in Region 4 with hometown as Region 1
  pop42 ; population in Region 4 with hometown as Region 2
  pop43 ; population in Region 4 with hometown as Region 3
  pop44 ; population in Region 4 with hometown as Region 4
  pop45 ; population in Region 4 with hometown as Region 5
  pop51 ; population in Region 5 with hometown as Region 1
  pop52 ; population in Region 5 with hometown as Region 2
  pop53 ; population in Region 5 with hometown as Region 3
  pop54 ; population in Region 5 with hometown as Region 4
  pop55 ; population in Region 5 with hometown as Region 5
]

turtles-own [
  origin ; current location at the beginning of the step
  water-per-person ; per capita water availability at the beginning of the step
  out-prob ; probability to leave the current location (first stage decision) at the beginning of the step
  stay-prob ; probability to stay in the current location (first stage decision) at the beginning of the step
  water-prob ; water-related probabilistic calculation in the second-stage decision
  dist-prob ; distance-related probabilistic calculation in the second-stage decision
  social-prob ; social-related probabilistic calculation in the second-stage decision
  migration-prob ; second-stage probability to move to other 4 regions
  migration-prob-cumulative ; cumulative second-stage probability
  dice1 ; random dice for first-stage decision
  dice2 ; random dice for second-stage decision
  destination ; location to move to
  x1 ; natural factor (per capita water availability)
  x2 ; social factor (population in the current location from the same hometown divided by population in the current location @ the beginning of the step)
  migrate? ; true when a resident moves to other region
  prev-loc ; location at the beginning of the step
]

patches-own [
  water-available ; water available in each region
  population ; the number of residents in each region
  city-dist ; a list of distance to other regions
]

breed [ residents resident ]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;SETUP;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  create-regions
  ini-water-availability
  update-pop
  reset-ticks
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;SETUP-RELATED;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to create-regions
  ; create regions and locate 100 residents in each region
  let i 0
  set regions 5
  set-default-shape residents "circle"
  repeat regions [
    ask patch i 0 [
      set pcolor blue
      sprout-residents 100 [
        set size 0.5
        set origin i
        set migrate? false
      ]
      let j 0
    ]
    set i i + 1
  ]

  set pop1 100
  set pop2 100
  set pop3 100
  set pop4 100
  set pop5 100

  set pop11 100
  set pop12 0
  set pop13 0
  set pop14 0
  set pop15 0
  set pop21 0
  set pop22 100
  set pop23 0
  set pop24 0
  set pop25 0
  set pop31 0
  set pop32 0
  set pop33 100
  set pop34 0
  set pop35 0
  set pop41 0
  set pop42 0
  set pop43 0
  set pop44 100
  set pop45 0
  set pop51 0
  set pop52 0
  set pop53 0
  set pop54 0
  set pop55 100

end

to ini-water-availability
  ; set water availability per region
  ask patches [
    set water-available (mean-water - 2 * gradient) + (pxcor * gradient)
    set population 100
    set city-dist []
    let i 0
    repeat regions [
      set city-dist (sentence city-dist abs (pxcor - i))
      set i i + 1
    ]
  ]
  ask residents [
    set water-per-person [water-available] of patch-here / 100
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;GO;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  if ticks = 2001 [ ask patch 0 0 [set water-available (water-available * 0.5)] ] ; disturb Region 1 by dropping water availability to a half
  calculate-first
  calculate-second
  migrate
  water-distribute
  update-pop
  tick
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;GO-RELATED;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to calculate-first
  ;; First stage probability for deciding whether or not a resident should go out of the city
  ask residents [
    set prev-loc pxcor
    set dice1 random-float 1
    let myorigin origin
    let mypx pxcor
    let wat item 0 ([water-available] of (patches with [pxcor = mypx and pycor = 0]))
    let Nall count residents with [origin = myorigin]
    let Nhere count residents with [origin = myorigin and pxcor = mypx]
    set x1 (wat) / (count residents with [pxcor = mypx and pycor = 0])
    set x2 Nhere / Nall
    ; calculate first-stage probability based on the chosen factor configuration
    ifelse config = "ADD" [
      set stay-prob ((exp (bet11 * (x1 - alp1) + bet12 * (x2 - alp2))) / (1 + exp (bet11 * (x1 - alp1) + bet12 * (x2 - alp2))))
      set out-prob (1 - stay-prob)
    ]
    [
      ifelse config = "AND" [
        set stay-prob ((exp (bet11 * (x1 - alp1) + bet12 * (x2 - alp2))) / (1 + exp (bet11 * (x1 - alp1)) + exp (bet12 * (x2 - alp2)) + exp (bet11 * (x1 - alp1) + bet12 * (x2 - alp2))) )
        set out-prob (1 - stay-prob)
      ]
      [
        set stay-prob ((exp (bet11 * (x1 - alp1) + bet12 * (x2 - alp2)) + exp (bet11 * (x1 - alp1)) + exp (bet12 * (x2 - alp2))) / (1 + exp (bet11 * (x1 - alp1)) + exp (bet12 * (x2 - alp2)) + exp (bet11 * (x1 - alp1) + bet12 * (x2 - alp2))))
        set out-prob (1 - stay-prob)
      ]
    ]
    ; if dice is greater than out-probability, a resident will stay in the current region
    ifelse dice1 > out-prob [
      set migrate? false
      set migration-prob [0 0 0 0 0]
    ]
    [
      set migrate? true
    ]
  ]
end

to calculate-second
  ;; Second stage probability for deciding which city to go
  ask residents with [migrate? = true] [
    let k 0
    set water-prob []
    set social-prob []
    set dist-prob []
    set migration-prob []
    let my-city pxcor
    set dice2 random-float 1
    let myorigin origin
    ;; Get a migration probability list for each city
    repeat regions [
      let wj ([water-available] of patch k 0) / ([population] of patch k 0)
      let wo ([water-available] of patch-here) / ([population] of patch-here)
      let Nj ((count turtles with [origin = myorigin and pxcor = k]) / (count turtles with [pxcor = k]))
      let No ((count turtles with [origin = myorigin and pxcor = my-city]) / (count turtles with [pxcor = my-city]))
      let x23 item k [city-dist] of patch-here
      let x21 wj - wo
      let x22 Nj - No
      set water-prob (sentence water-prob (exp (bet21 * x21 )))
      set social-prob (sentence social-prob (exp (bet22 * x22)))
      set dist-prob (sentence dist-prob (exp (bet23 * x23)))
      ifelse x23 = 0 [
        set migration-prob sentence migration-prob 0
      ]
      [
        ifelse config = "ADD" [
          set migration-prob (sentence migration-prob (item k water-prob * item k social-prob * item k dist-prob / (1 + item k water-prob * item k social-prob) ))
        ]
        [
          ifelse config = "AND" [
            set migration-prob (sentence migration-prob ((item k water-prob * item k social-prob * item k dist-prob ) / (1 + item k water-prob + item k social-prob + ((item k water-prob) * (item k social-prob))) ))
          ]
          [
            set migration-prob (sentence migration-prob ((item k water-prob + item k social-prob + ((item k water-prob) * (item k social-prob))) * item k dist-prob / (1 + item k water-prob + item k social-prob + ((item k water-prob) * (item k social-prob))) ))
          ]
        ]
      ]
      set k k + 1
    ]
    let sum-prob (sum migration-prob)
    let a1 (item 0 migration-prob) / sum-prob
    let a2 (item 1 migration-prob) / sum-prob
    let a3 (item 2 migration-prob) / sum-prob
    let a4 (item 3 migration-prob) / sum-prob
    let a5 (item 4 migration-prob) / sum-prob
    set migration-prob-cumulative (list a1 (a1 + a2) (a1 + a2 + a3) (a1 + a2 + a3 + a4) 1)
  ]
end

to migrate
  ; move to the selected region based on the second-stage probability
  ask residents with [dice1 <= out-prob] [
    let m 0
    let o pxcor
    set destination m
    while [dice2 - item m migration-prob-cumulative > 0] [
      set m m + 1
    ]
    set destination m
    setxy m 0
  ]
end

to water-distribute
  ; update per capita water availability after every residents finish the migration process
  ask patches [
    let patch-px pxcor
    set population count residents with [xcor = patch-px]
  ]
  ask residents [
    set water-per-person [water-available] of patch-here / [population] of patch-here
  ]
end

to update-pop
  ; update the number of residents after every residents finish the migration process
  set pop1 ([population] of patch 0 0)
  set pop2 ([population] of patch 1 0)
  set pop3 ([population] of patch 2 0)
  set pop4 ([population] of patch 3 0)
  set pop5 ([population] of patch 4 0)
  set pop11 (count turtles with [pxcor = 0 and who < 100])
  set pop12 (count turtles with [pxcor = 0 and who < 200 and who >= 100])
  set pop13 (count turtles with [pxcor = 0 and who < 300 and who >= 200])
  set pop14 (count turtles with [pxcor = 0 and who < 400 and who >= 300])
  set pop15 (count turtles with [pxcor = 0 and who < 500 and who >= 400])
  set pop21 (count turtles with [pxcor = 1 and who < 100])
  set pop22 (count turtles with [pxcor = 1 and who < 200 and who >= 100])
  set pop23 (count turtles with [pxcor = 1 and who < 300 and who >= 200])
  set pop24 (count turtles with [pxcor = 1 and who < 400 and who >= 300])
  set pop25 (count turtles with [pxcor = 1 and who < 500 and who >= 400])
  set pop31 (count turtles with [pxcor = 2 and who < 100])
  set pop32 (count turtles with [pxcor = 2 and who < 200 and who >= 100])
  set pop33 (count turtles with [pxcor = 2 and who < 300 and who >= 200])
  set pop34 (count turtles with [pxcor = 2 and who < 400 and who >= 300])
  set pop35 (count turtles with [pxcor = 2 and who < 500 and who >= 400])
  set pop41 (count turtles with [pxcor = 3 and who < 100])
  set pop42 (count turtles with [pxcor = 3 and who < 200 and who >= 100])
  set pop43 (count turtles with [pxcor = 3 and who < 300 and who >= 200])
  set pop44 (count turtles with [pxcor = 3 and who < 400 and who >= 300])
  set pop45 (count turtles with [pxcor = 3 and who < 500 and who >= 400])
  set pop51 (count turtles with [pxcor = 4 and who < 100])
  set pop52 (count turtles with [pxcor = 4 and who < 200 and who >= 100])
  set pop53 (count turtles with [pxcor = 4 and who < 300 and who >= 200])
  set pop54 (count turtles with [pxcor = 4 and who < 400 and who >= 300])
  set pop55 (count turtles with [pxcor = 4 and who < 500 and who >= 400])
end

; calculate Simpson's index
to-report simpson1
  report (pop11 + pop12 + pop13 + pop14 + pop15) ^ 2 / (pop11 ^ 2 + pop12 ^ 2 + pop13 ^ 2 + pop14 ^ 2 + pop15 ^ 2 )
end

to-report simpson2
  report (pop21 + pop22 + pop23 + pop24 + pop25) ^ 2 / (pop21 ^ 2 + pop22 ^ 2 + pop23 ^ 2 + pop24 ^ 2 + pop25 ^ 2 )
end

to-report simpson3
  report (pop31 + pop32 + pop33 + pop34 + pop35) ^ 2 / (pop31 ^ 2 + pop32 ^ 2 + pop33 ^ 2 + pop34 ^ 2 + pop35 ^ 2 )
end

to-report simpson4
  report (pop41 + pop42 + pop43 + pop44 + pop45) ^ 2 / (pop41 ^ 2 + pop42 ^ 2 + pop43 ^ 2 + pop44 ^ 2 + pop45 ^ 2 )
end

to-report simpson5
  report (pop51 + pop52 + pop53 + pop54 + pop55) ^ 2 / (pop51 ^ 2 + pop52 ^ 2 + pop53 ^ 2 + pop54 ^ 2 + pop55 ^ 2 )
end
@#$#@#$#@
GRAPHICS-WINDOW
34
282
402
363
-1
-1
72.0
1
15
1
1
1
0
0
0
1
0
4
0
0
0
0
1
ticks
30.0

BUTTON
68
23
136
58
SETUP
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
69
73
155
106
GO-ONCE
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
166
74
272
107
GO-FOREVER
GO
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
50
391
100
436
pop1
count turtles with [pxcor = 0]
1
1
11

MONITOR
122
391
172
436
pop2
count turtles with [pxcor = 1]
17
1
11

MONITOR
192
391
242
436
pop3
count turtles with [pxcor = 2]
17
1
11

MONITOR
265
390
315
435
pop4
count turtles with [pxcor = 3]
17
1
11

MONITOR
339
390
389
435
pop5
count turtles with [pxcor = 4]
17
1
11

PLOT
475
91
737
241
Population distribution
Regions
Populations
0.0
5.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "plot-pen-reset\nset-plot-pen-color black\nplot count turtles with [pxcor = 0]\nset-plot-pen-color blue\nplot count turtles with [pxcor = 1]\nset-plot-pen-color red\nplot count turtles with [pxcor = 2]\nset-plot-pen-color green\nplot count turtles with [pxcor = 3]\nset-plot-pen-color yellow\nplot count turtles with [pxcor = 4]"

PLOT
50
116
370
276
Water available in each region
NIL
Regional water
0.0
4.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" "plot-pen-reset\nset-plot-pen-color red\nplot [water-available] of patch 0 0 \nset-plot-pen-color red\nplot [water-available] of patch 1 0 \nset-plot-pen-color red\nplot [water-available] of patch 2 0 \nset-plot-pen-color red\nplot [water-available] of patch 3 0 \nset-plot-pen-color red\nplot [water-available] of patch 4 0 \nset-plot-pen-color red"

SLIDER
1041
94
1213
127
mean-water
mean-water
50
150
100.0
1
1
NIL
HORIZONTAL

SLIDER
1041
135
1213
168
gradient
gradient
-20
0
-10.0
1
1
NIL
HORIZONTAL

SLIDER
1041
174
1213
207
bet11
bet11
1.5
20
4.0
0.05
1
NIL
HORIZONTAL

SLIDER
1041
210
1213
243
bet12
bet12
0
7
4.0
0.02
1
NIL
HORIZONTAL

SLIDER
1041
248
1213
281
alp1
alp1
-3
3
0.3
0.01
1
NIL
HORIZONTAL

SLIDER
1041
284
1213
317
alp2
alp2
-3
3
0.3
0.05
1
NIL
HORIZONTAL

SLIDER
1041
322
1213
355
bet21
bet21
0.2
22
4.0
0.01
1
NIL
HORIZONTAL

SLIDER
1041
357
1213
390
bet22
bet22
0.25
10
4.0
0.01
1
NIL
HORIZONTAL

SLIDER
1041
394
1213
427
bet23
bet23
-10
-0.05
-4.0
0.01
1
NIL
HORIZONTAL

MONITOR
46
463
103
512
water1
[water-available] of patch 0 0
17
1
12

MONITOR
119
464
176
513
water2
[water-available] of patch 1 0
17
1
12

MONITOR
189
465
244
514
water3
[water-available] of patch 2 0
17
1
12

MONITOR
261
465
318
514
water4
[water-available] of patch 3 0
17
1
12

MONITOR
335
465
392
514
water5
[water-available] of patch 4 0
17
1
12

PLOT
476
250
737
479
Population timeseries
time
populations
0.0
10.0
50.0
110.0
true
true
"" ""
PENS
"pop1" 1.0 0 -16777216 true "" "plot count turtles with [pxcor = 0]"
"pop2" 1.0 0 -13345367 true "" "plot count turtles with [pxcor = 1]"
"pop3" 1.0 0 -2674135 true "" "plot count turtles with [pxcor = 2]"
"pop4" 1.0 0 -10899396 true "" "plot count turtles with [pxcor = 3]"
"pop5" 1.0 0 -1184463 true "" "plot count turtles with [pxcor = 4]"

MONITOR
45
547
102
592
w1/p1
([water-available] of patch 0 0) / (count turtles with [pxcor = 0])
4
1
11

TEXTBOX
56
344
143
362
Region 1
11
9.9
1

TEXTBOX
127
343
277
361
Region 2
11
9.9
1

TEXTBOX
198
343
348
361
Region 3
11
9.9
1

TEXTBOX
272
343
422
361
Region 4
11
9.9
1

TEXTBOX
343
343
395
361
Region 5
11
9.9
1

TEXTBOX
40
373
190
391
Populations in each region
12
0.0
1

TEXTBOX
35
444
320
474
Water availability in each region
12
0.0
1

TEXTBOX
35
527
405
557
Water allocated to each resident (regional water / population)
12
0.0
1

MONITOR
118
547
175
592
w2/p2
([water-available] of patch 1 0) / (count turtles with [pxcor = 1])
4
1
11

MONITOR
187
547
244
592
w3/p3
([water-available] of patch 2 0) / (count turtles with [pxcor = 2])
4
1
11

MONITOR
260
547
317
592
w4/p4
([water-available] of patch 3 0) / (count turtles with [pxcor = 3])
4
1
11

MONITOR
335
547
392
592
w5/p5
([water-available] of patch 4 0) / (count turtles with [pxcor = 4])
4
1
11

TEXTBOX
481
42
710
80
Spatial distribution of populations
15
0.0
1

TEXTBOX
750
56
937
94
Mixing of cultural groups
15
0.0
1

PLOT
749
91
1005
241
Cultural mixing distribution
Regions
Dj
0.0
5.0
1.0
5.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "plot-pen-reset\nset-plot-pen-color black\nplot simpson1\nset-plot-pen-color blue\nplot simpson2\nset-plot-pen-color red\nplot simpson3\nset-plot-pen-color green\nplot simpson4\nset-plot-pen-color yellow\nplot simpson5"

PLOT
749
250
1007
479
Cultural mixing timeseries
time
Dj
0.0
10.0
1.0
5.0
true
true
"" ""
PENS
"region 1" 1.0 0 -16777216 true "" "plot simpson1"
"region 2" 1.0 0 -13345367 true "" "plot simpson2"
"region 3" 1.0 0 -2674135 true "" "plot simpson3"
"region 4" 1.0 0 -10899396 true "" "plot simpson4"
"region 5" 1.0 0 -1184463 true "" "plot simpson5"

TEXTBOX
286
10
454
58
Factor configuration:\nhow natural and social factors are incorporated
13
0.0
1

TEXTBOX
1041
58
1191
77
Inputs
15
0.0
1

CHOOSER
287
60
425
105
config
config
"ADD" "AND" "OR"
0

TEXTBOX
449
20
599
579
|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n
12
0.0
1

TEXTBOX
1019
29
1169
588
|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n|\n
12
0.0
1

@#$#@#$#@
## WHAT IS IT?

This proof-of-concept model explores the effects of how social and natural factors are incorporated (factor configuration) in environmentally induced migration.

## HOW IT WORKS

The model assumes that residents build social ties with the residents from the same hometown (cultural affinity). Another assumption is that the regional water is equally distributed to the residents in the region. The model has two stages. First, a resident decides whether to stay or to leave the current region. Once a resident decided to leave, he/she then selects a region to migrate to. In the first-stage migration decision, per capita water availability and fraction of populations from the same hometown build the probabilistic equation according to the factor configuration. In the second-stage migration decision, relative per capita water availability, relative fraction of populations from the same hometown, and distance build the probabilistic equation according to the factor configuration. At t=2001, Region 1 is disturbed by 50% drop of water availability.

## HOW TO USE IT

The interface is divided into 3 columns: left, center, and right.

In the left column, the model has buttons for setup, one-step run (go-once), and infinite-step runs (go-forever). You can choose factor configuration in the "config" chooser: "ADD", "AND", "OR".

In the center column, there are plots for population and cultural mixing. The upper row shows population and cultural mixing distributions over five regions at the current time step. The lower row shows time series of population and cultural mixing in five regions.

In the right column, there are input controllers. The following is the explanation about the inputs:
mean-water (m): Mean of available water for five regions. This input is directly related to the amount of water supply over five regions.
gradient (s): A slope of water availability over five regions. Related to how equally/inequally water is distributed in five regions.
bet11 (beta_1^(1)): Weight of natural factor (water availability) in calculating first-stage migration
probability. Controls a shape of logistic function for the first-stage probability (flat
curve versus steep curve).
bet12 (beta_1^(2)): Weight of social factor (cultural affinity) in calculating first-stage migration probability. Controls a shape of logistic function for the first-stage probability (flat curve versus steep curve).
alp1 (alpha^(1)): Increase/decrease the probability of a resident to leave the current location (controls degrees of first-stage probability) with respect to water availability.
alp2 (alpha^(2)): Increase/decrease the probability of a resident to leave the current location (controls degrees of first-stage probability) with respect to cultural affinity.
bet21 (beta_2^(1)): Weight of natural factor (water availability) in calculating second-stage migration probability. Controls a shape of logistic function for the second-stage probability (flat curve versus steep curve).
bet22 (beta_2^(2)): Weight of social factor (cultural affinity) in calculating second-stage migration
probability. Controls a shape of logistic function for the second-stage probability (flat
curve versus steep curve).
bet23 (beta_2^(3)): Weight of distance factor in calculating second-stage migration probability. Controls a shape of logistic function for the second-stage probability (flat curve versus steep curve).

## CREDITS AND REFERENCES

This model is in preparation for a submission in JASSS: Oh W, Carmona Cabrero A, Munoz-Carpena R, Muneepeerakul R (In prep.) On the interplay among multiple factors in an agent-based model: Effects of factor configuration in a proof-of-concept migration model, JASSS
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="popsimp2" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2001"/>
    <metric>count turtles with [pxcor = 0]</metric>
    <metric>count turtles with [pxcor = 1]</metric>
    <metric>count turtles with [pxcor = 2]</metric>
    <metric>count turtles with [pxcor = 3]</metric>
    <metric>count turtles with [pxcor = 4]</metric>
    <metric>simpson1</metric>
    <metric>simpson2</metric>
    <metric>simpson3</metric>
    <metric>simpson4</metric>
    <metric>simpson5</metric>
    <metric>count turtles with [xcor = 0 and origin = 0]</metric>
    <metric>count turtles with [xcor = 0 and origin = 1]</metric>
    <metric>count turtles with [xcor = 0 and origin = 2]</metric>
    <metric>count turtles with [xcor = 0 and origin = 3]</metric>
    <metric>count turtles with [xcor = 0 and origin = 4]</metric>
    <metric>count turtles with [xcor = 1 and origin = 0]</metric>
    <metric>count turtles with [xcor = 1 and origin = 1]</metric>
    <metric>count turtles with [xcor = 1 and origin = 2]</metric>
    <metric>count turtles with [xcor = 1 and origin = 3]</metric>
    <metric>count turtles with [xcor = 1 and origin = 4]</metric>
    <metric>count turtles with [xcor = 2 and origin = 0]</metric>
    <metric>count turtles with [xcor = 2 and origin = 1]</metric>
    <metric>count turtles with [xcor = 2 and origin = 2]</metric>
    <metric>count turtles with [xcor = 2 and origin = 3]</metric>
    <metric>count turtles with [xcor = 2 and origin = 4]</metric>
    <metric>count turtles with [xcor = 3 and origin = 0]</metric>
    <metric>count turtles with [xcor = 3 and origin = 1]</metric>
    <metric>count turtles with [xcor = 3 and origin = 2]</metric>
    <metric>count turtles with [xcor = 3 and origin = 3]</metric>
    <metric>count turtles with [xcor = 3 and origin = 4]</metric>
    <metric>count turtles with [xcor = 4 and origin = 0]</metric>
    <metric>count turtles with [xcor = 4 and origin = 1]</metric>
    <metric>count turtles with [xcor = 4 and origin = 2]</metric>
    <metric>count turtles with [xcor = 4 and origin = 3]</metric>
    <metric>count turtles with [xcor = 4 and origin = 4]</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="1.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="13"/>
      <value value="14"/>
      <value value="15"/>
      <value value="16"/>
      <value value="17"/>
      <value value="18"/>
      <value value="19"/>
      <value value="20"/>
      <value value="21"/>
      <value value="22"/>
      <value value="23"/>
      <value value="24"/>
      <value value="25"/>
      <value value="26"/>
      <value value="27"/>
      <value value="28"/>
      <value value="29"/>
      <value value="30"/>
      <value value="31"/>
      <value value="32"/>
      <value value="33"/>
      <value value="34"/>
      <value value="35"/>
      <value value="36"/>
      <value value="37"/>
      <value value="38"/>
      <value value="39"/>
      <value value="40"/>
      <value value="41"/>
      <value value="42"/>
      <value value="43"/>
      <value value="44"/>
      <value value="45"/>
      <value value="46"/>
      <value value="47"/>
      <value value="48"/>
      <value value="49"/>
      <value value="50"/>
      <value value="51"/>
      <value value="52"/>
      <value value="53"/>
      <value value="54"/>
      <value value="55"/>
      <value value="56"/>
      <value value="57"/>
      <value value="58"/>
      <value value="59"/>
      <value value="60"/>
      <value value="61"/>
      <value value="62"/>
      <value value="63"/>
      <value value="64"/>
      <value value="65"/>
      <value value="66"/>
      <value value="67"/>
      <value value="68"/>
      <value value="69"/>
      <value value="70"/>
      <value value="71"/>
      <value value="72"/>
      <value value="73"/>
      <value value="74"/>
      <value value="75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="regionpop1" repetitions="75" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="3001"/>
    <metric>count turtles with [xcor = 0 and origin = 0]</metric>
    <metric>count turtles with [xcor = 0 and origin = 1]</metric>
    <metric>count turtles with [xcor = 0 and origin = 2]</metric>
    <metric>count turtles with [xcor = 0 and origin = 3]</metric>
    <metric>count turtles with [xcor = 0 and origin = 4]</metric>
    <metric>count turtles with [xcor = 1 and origin = 0]</metric>
    <metric>count turtles with [xcor = 1 and origin = 1]</metric>
    <metric>count turtles with [xcor = 1 and origin = 2]</metric>
    <metric>count turtles with [xcor = 1 and origin = 3]</metric>
    <metric>count turtles with [xcor = 1 and origin = 4]</metric>
    <metric>count turtles with [xcor = 2 and origin = 0]</metric>
    <metric>count turtles with [xcor = 2 and origin = 1]</metric>
    <metric>count turtles with [xcor = 2 and origin = 2]</metric>
    <metric>count turtles with [xcor = 2 and origin = 3]</metric>
    <metric>count turtles with [xcor = 2 and origin = 4]</metric>
    <metric>count turtles with [xcor = 3 and origin = 0]</metric>
    <metric>count turtles with [xcor = 3 and origin = 1]</metric>
    <metric>count turtles with [xcor = 3 and origin = 2]</metric>
    <metric>count turtles with [xcor = 3 and origin = 3]</metric>
    <metric>count turtles with [xcor = 3 and origin = 4]</metric>
    <metric>count turtles with [xcor = 4 and origin = 0]</metric>
    <metric>count turtles with [xcor = 4 and origin = 1]</metric>
    <metric>count turtles with [xcor = 4 and origin = 2]</metric>
    <metric>count turtles with [xcor = 4 and origin = 3]</metric>
    <metric>count turtles with [xcor = 4 and origin = 4]</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="1.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="400"/>
    <metric>count turtles with [pxcor = 0]</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment1" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="400"/>
    <metric>count turtles with [pxcor = 0]</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.67"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="2.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="1.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="pop-simp1" repetitions="75" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="3000"/>
    <metric>count turtles with [pxcor = 0]</metric>
    <metric>count turtles with [pxcor = 1]</metric>
    <metric>count turtles with [pxcor = 2]</metric>
    <metric>count turtles with [pxcor = 3]</metric>
    <metric>count turtles with [pxcor = 4]</metric>
    <metric>simpson1</metric>
    <metric>simpson2</metric>
    <metric>simpson3</metric>
    <metric>simpson4</metric>
    <metric>simpson5</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment0" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="5000"/>
    <metric>120 / (count turtles with [pxcor = 0])</metric>
    <metric>(count turtles with [pxcor = 0 and origin = 0]) / (count turtles with [pxcor = 0])</metric>
    <metric>(count turtles with [pxcor = 0 and origin = 1]) / (count turtles with [pxcor = 0])</metric>
    <metric>(count turtles with [pxcor = 0 and origin = 2]) / (count turtles with [pxcor = 0])</metric>
    <metric>(count turtles with [pxcor = 0 and origin = 3]) / (count turtles with [pxcor = 0])</metric>
    <metric>(count turtles with [pxcor = 0 and origin = 4]) / (count turtles with [pxcor = 0])</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="track" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>[x1] of turtle 0</metric>
    <metric>[x2] of turtle 0</metric>
    <metric>[pxcor] of turtle 0</metric>
    <metric>[x1] of turtle 100</metric>
    <metric>[x2] of turtle 100</metric>
    <metric>[pxcor] of turtle 100</metric>
    <metric>[x1] of turtle 200</metric>
    <metric>[x2] of turtle 200</metric>
    <metric>[pxcor] of turtle 200</metric>
    <metric>[x1] of turtle 300</metric>
    <metric>[x2] of turtle 300</metric>
    <metric>[pxcor] of turtle 300</metric>
    <metric>[x1] of turtle 400</metric>
    <metric>[x2] of turtle 400</metric>
    <metric>[pxcor] of turtle 400</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="tracki1" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="3001"/>
    <metric>[x1] of turtle 0</metric>
    <metric>[x2] of turtle 0</metric>
    <metric>[prev-loc] of turtle 0</metric>
    <metric>[x1] of turtle 100</metric>
    <metric>[x2] of turtle 100</metric>
    <metric>[prev-loc] of turtle 100</metric>
    <metric>[x1] of turtle 200</metric>
    <metric>[x2] of turtle 200</metric>
    <metric>[prev-loc] of turtle 200</metric>
    <metric>[x1] of turtle 300</metric>
    <metric>[x2] of turtle 300</metric>
    <metric>[prev-loc] of turtle 300</metric>
    <metric>[x1] of turtle 400</metric>
    <metric>[x2] of turtle 400</metric>
    <metric>[prev-loc] of turtle 400</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="tt3" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="20000"/>
    <metric>[x1] of turtle 0</metric>
    <metric>[x2] of turtle 0</metric>
    <metric>[pxcor] of turtle 0</metric>
    <metric>[x1] of turtle 100</metric>
    <metric>[x2] of turtle 100</metric>
    <metric>[pxcor] of turtle 100</metric>
    <metric>[x1] of turtle 200</metric>
    <metric>[x2] of turtle 200</metric>
    <metric>[pxcor] of turtle 200</metric>
    <metric>[x1] of turtle 300</metric>
    <metric>[x2] of turtle 300</metric>
    <metric>[pxcor] of turtle 300</metric>
    <metric>[x1] of turtle 400</metric>
    <metric>[x2] of turtle 400</metric>
    <metric>[pxcor] of turtle 400</metric>
    <enumeratedValueSet variable="mean-water">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet11">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet23">
      <value value="-7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet12">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="restrict-par">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed">
      <value value="69"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp1">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet21">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alp2">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="config">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bet22">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gradient">
      <value value="-10"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
